@@ -1,14 +1,14 @@
 # -*- perl -*-
 ##----------------------------------------------------------------------------
-## DB/Object/SQLite.pm
-## Version 0.3
-## Copyright(c) 2019 Jacques Deguest
+## Database Object Interface - ~/lib/DB/Object/SQLite.pm
+## Version 0.4
+## Copyright(c) 2019 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2017/07/19
 ## Modified 2019/08/25
-## All rights reserved.
+## All rights reserved
 ## 
-## This program is free software; you can redistribute it and/or modify it 
+## This program is free software; you can redistribute  it  and/or  modify  it
 ## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 ## This is the subclassable module for driver specific ones.
@@ -34,9 +34,10 @@ BEGIN
     use DateTime::TimeZone;
     use DateTime::Format::Strptime;
 	use Number::Format;
+	use TryCatch;
     our( $VERSION, $DB_ERRSTR, $ERROR, $DEBUG, $CONNECT_VIA, $CACHE_QUERIES, $CACHE_SIZE );
     our( $CACHE_TABLE, $USE_BIND, $USE_CACHE, $MOD_PERL, @DBH );
-    $VERSION     = '0.3';
+    $VERSION     = '0.4';
     use Devel::Confess;
 };
 
